(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[802],{3102:function(e,r,t){Promise.resolve().then(t.bind(t,902))},902:function(e,r,t){"use strict";t.r(r),t.d(r,{default:function(){return h}});var n=t(7821),s=t(9164),l=t(3153),a=t(9063),o=t(8078),i=t(9792),c=t(7211);function d(e){let{className:r,children:t,...s}=e;return(0,n.jsxs)(i.fC,{"data-slot":"scroll-area",className:(0,c.cn)("relative",r),...s,children:[(0,n.jsx)(i.l_,{"data-slot":"scroll-area-viewport",className:"focus-visible:ring-ring/50 size-full rounded-[inherit] transition-[color,box-shadow] outline-none focus-visible:ring-[3px] focus-visible:outline-1",children:t}),(0,n.jsx)(u,{}),(0,n.jsx)(i.Ns,{})]})}function u(e){let{className:r,orientation:t="vertical",...s}=e;return(0,n.jsx)(i.gb,{"data-slot":"scroll-area-scrollbar",orientation:t,className:(0,c.cn)("flex touch-none p-px transition-colors select-none","vertical"===t&&"h-full w-2.5 border-l border-l-transparent","horizontal"===t&&"h-2.5 flex-col border-t border-t-transparent",r),...s,children:(0,n.jsx)(i.q4,{"data-slot":"scroll-area-thumb",className:"bg-border relative flex-1 rounded-full"})})}var f=t(8504),p=t(6446);let x={privacy:s.wnM,terms_and_conditions:s.s0H,myeclpay_terms_of_service:s.Gen,support:s.CyC},m=()=>{let e=(0,f.useSearchParams)().get("path");e&&e in x||(0,f.notFound)();let[r,t]=(0,o.useState)("");return(0,o.useEffect)(()=>{(async()=>{let r=await x[e]().then(e=>e.data);"string"==typeof r&&t(r)})()},[e]),(0,n.jsx)("article",{className:"prose lg:prose-lg prose-p:text-justify prose-p:leading-6 prose-p:my-4 prose-ul:list-outside prose-ul:pl-4 prose-ul:my-0 prose-li:my-0 prose-li:pl-0 prose-headings:font-semibold prose-headings:my-4 prose-h2:text-2xl prose-h1:text-4xl marker:text-foreground marker:mx-0 max-w-none mx-3  ",children:(0,n.jsx)(p.UG,{children:r})})};var h=()=>(0,n.jsx)(l.G,{title:"Document",description:"Consultez son contenu",children:(0,n.jsx)(a.H,{radius:400,children:(0,n.jsx)(d,{className:"rounded-md bg-background h-[62vh]",children:(0,n.jsx)(o.Suspense,{children:(0,n.jsx)(m,{})})})})})},3153:function(e,r,t){"use strict";t.d(r,{G:function(){return l}});var n=t(7821),s=t(8006);let l=e=>{let{title:r,description:t,children:l}=e;return(0,n.jsx)("div",{className:"m-4 flex h-screen [&>div]:w-full",children:(0,n.jsxs)(s.Zb,{className:"m-auto rounded-xl border bg-white bg-opacity-80 shadow backdrop-blur",children:[(0,n.jsxs)(s.Ol,{children:[(0,n.jsx)(s.ll,{className:"text-xl",children:r}),(0,n.jsx)(s.SZ,{children:t})]}),(0,n.jsx)(s.aY,{className:"w-full lg:w-[700px]",children:l})]})})}},9063:function(e,r,t){"use strict";t.d(r,{H:function(){return d}});var n=t(3620),s=t(7821),l=t(8657),a=t(474),o=t(1992),i=t(8078);function c(){let e=(0,n._)(["\n        radial-gradient(\n          "," circle at ","px ","px,\n          hsl(var(--primary)),\n          transparent 80%\n        )\n      "]);return c=function(){return e},e}let d=e=>{var r;let t=null!==(r=e.radius)&&void 0!==r?r:100,[n,d]=i.useState(!1),u=(0,l.c)(0),f=(0,l.c)(0);return(0,s.jsx)(a.E.div,{style:{background:(0,o.Y)(c(),n?t+"px":"0px",u,f)},onMouseMove:function(e){let{currentTarget:r,clientX:t,clientY:n}=e,{left:s,top:l}=r.getBoundingClientRect();u.set(t-s),f.set(n-l)},onMouseEnter:()=>d(!0),onMouseLeave:()=>d(!1),className:"group/input rounded-lg p-[2px] transition duration-300",children:e.children})}},8006:function(e,r,t){"use strict";t.d(r,{Ol:function(){return o},SZ:function(){return c},Zb:function(){return a},aY:function(){return d},eW:function(){return u},ll:function(){return i}});var n=t(7821),s=t(8078),l=t(7211);let a=s.forwardRef((e,r)=>{let{className:t,...s}=e;return(0,n.jsx)("div",{ref:r,className:(0,l.cn)("rounded-lg border bg-card text-card-foreground shadow-sm",t),...s})});a.displayName="Card";let o=s.forwardRef((e,r)=>{let{className:t,...s}=e;return(0,n.jsx)("div",{ref:r,className:(0,l.cn)("flex flex-col space-y-1.5 p-6",t),...s})});o.displayName="CardHeader";let i=s.forwardRef((e,r)=>{let{className:t,...s}=e;return(0,n.jsx)("h3",{ref:r,className:(0,l.cn)("text-2xl font-semibold leading-none tracking-tight",t),...s})});i.displayName="CardTitle";let c=s.forwardRef((e,r)=>{let{className:t,...s}=e;return(0,n.jsx)("p",{ref:r,className:(0,l.cn)("text-sm text-muted-foreground",t),...s})});c.displayName="CardDescription";let d=s.forwardRef((e,r)=>{let{className:t,...s}=e;return(0,n.jsx)("div",{ref:r,className:(0,l.cn)("p-6 pt-0",t),...s})});d.displayName="CardContent";let u=s.forwardRef((e,r)=>{let{className:t,...s}=e;return(0,n.jsx)("div",{ref:r,className:(0,l.cn)("flex items-center p-6 pt-0",t),...s})});u.displayName="CardFooter"}},function(e){e.O(0,[436,764,921,517,115,364,744],function(){return e(e.s=3102)}),_N_E=e.O()}]);