"use strict";(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[517],{9164:function(n,r,u){u.d(r,{Gen:function(){return t.Gen},wnM:function(){return t.wnM},CyC:function(){return t.CyC},s0H:function(){return t.s0H},ngE:function(){return t.ngE},yvu:function(){return t.yvu},SSm:function(){return t.SSm},ZiC:function(){return t.ZiC},u7z:function(){return t.u7z}});var t=u(9948)},9948:function(n,r,u){u.d(r,{CyC:function(){return o},Gen:function(){return i},SSm:function(){return d},ZiC:function(){return v},ngE:function(){return c},rmt:function(){return a},s0H:function(){return l},u7z:function(){return f},wnM:function(){return e},yvu:function(){return s}});var t=u(4397);let e=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).get({...n,url:"/privacy"})},l=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).get({...n,url:"/terms-and-conditions"})},i=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).get({...n,url:"/myeclpay-terms-of-service"})},o=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).get({...n,url:"/support"})},c=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).get({...n,url:"/variables"})},v=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).post({...n,url:"/users/create"})},s=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).post({...n,url:"/users/activate"})},a=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).post({...n,url:"/users/recover"})},f=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).post({...n,url:"/users/reset-password"})},d=n=>{var r;return(null!==(r=null==n?void 0:n.client)&&void 0!==r?r:t.Lp).post({...n,url:"/users/change-password"})}},7211:function(n,r,u){u.d(r,{cn:function(){return l}});var t=u(2605),e=u(1638);function l(){for(var n=arguments.length,r=Array(n),u=0;u<n;u++)r[u]=arguments[u];return(0,e.m6)((0,t.W)(r))}}}]);